@@ -23,6 +23,7 @@ Revision History
 extern "C" {
 #endif
 
+#include "eficompiler.h"
 #include "efidebug.h"
 #include "efipart.h"
 #if defined(_M_X64) || defined(__x86_64__) || defined(__amd64__)
@@ -714,6 +715,14 @@ AsciiPrint (
     ...
     );
 
+UINTN
+AsciiSPrint (
+    OUT CHAR8         *Str,
+    IN UINTN          StrSize,
+    IN CONST CHAR8    *fmt,
+    ...
+);
+
 UINTN
 AsciiVSPrint(
     OUT CHAR8         *Str,
